@@ -173,7 +173,6 @@ def piggo_upload(siteinfo,file1,record_path,qbinfo,basic,hashlist):
     else:
         uplver='no'
 
-    raw_cookies = "cf_clearance=EFeDqK.AwL.6jrr3Szq8P16WD0mnX5Gw6jdtFeZw0Fw-1658382309-0-150; c_secure_uid=MTAxNzg%3D; c_secure_pass=681d0177f1633f622820ab7ef57ba076; c_secure_ssl=eWVhaA%3D%3D; c_secure_tracker_ssl=eWVhaA%3D%3D; c_secure_login=bm9wZQ%3D%3D"
     torrent_file = file1.torrentpath
     post_url = "https://piggo.me/takeupload.php"
 
@@ -202,27 +201,7 @@ def piggo_upload(siteinfo,file1,record_path,qbinfo,basic,hashlist):
             "tags[]": tags,
             }
 
-    #r = requests.post(post_url, cookies=cookies_raw2jar(raw_cookies),data=other_data, files=file_tup)
     scraper=cloudscraper.create_scraper()
     r = scraper.post(post_url, cookies=cookies_raw2jar(siteinfo.cookie),data=other_data, files=file_tup)
-    
-    logger.info('已发布成功')
 
-    String_url =finduploadurl(r)
-
-    downloadurl=finddownloadurl(r)
-    if downloadurl=='已存在':
-        return True,fileinfo+'种子发布失败,失败原因:种子'+downloadurl+',当前网址:'+String_url
-
-    
-    recordupload(os.path.join(record_path,siteinfo.sitename+'_torrent.csv'),file1,String_url,downloadurl)
-    if not downloadurl =='':
-        res=qbseed(url=downloadurl,filepath=file1.downloadpath,qbinfo=qbinfo,category=file1.pathinfo.category,hashlist=hashlist)
-        if res:
-            return True,fileinfo+'种子发布成功,种子链接:'+downloadurl+',当前网址:'+String_url
-        else:
-            return True,fileinfo+'种子发布成功,但是添加种子失败,请手动添加种子，种子链接:'+downloadurl+',当前网址:'+String_url
-    else:
-        return False,fileinfo+'未找到下载链接,当前网址:'+String_url
-
-    
+    return afterupload(r,fileinfo,record_path,siteinfo,file1,qbinfo,hashlist)
\ No newline at end of file
