@@ -10,6 +10,27 @@ import re
 import qbittorrentapi
 from http.cookies import SimpleCookie
 
+
+def afterupload(r,fileinfo,record_path,siteinfo,file1,qbinfo,hashlist):
+    if r.status_code==200:
+        logger.info('已发布成功')
+    else:
+        logger.warning('发布种子发生错误，错误代码:'+str(r.status_code)+' ,错误信息:'+str(r.reason))
+        return False,fileinfo+' 发布种子发生错误，错误代码:'+str(r.status_code)+' ,错误信息:'+str(r.reason)
+    String_url =finduploadurl(r)
+    downloadurl=finddownloadurl(r)
+    if downloadurl=='已存在':
+        return True,fileinfo+'种子发布失败,失败原因:种子'+downloadurl+',当前网址:'+String_url
+    recordupload(os.path.join(record_path,siteinfo.sitename+'_torrent.csv'),file1,String_url,downloadurl)
+    if not downloadurl =='':
+        res=qbseed(url=downloadurl,filepath=file1.downloadpath,qbinfo=qbinfo,category=file1.pathinfo.category,hashlist=hashlist)
+        if res:
+            return True,fileinfo+'种子发布成功,种子链接:'+downloadurl+',当前网址:'+String_url
+        else:
+            return True,fileinfo+'种子发布成功,但是添加种子失败,请手动添加种子，种子链接:'+downloadurl+',当前网址:'+String_url
+    else:
+        return False,fileinfo+'未找到下载链接,当前网址:'+String_url
+
 def cookies_raw2jar(raw: str) -> dict:
     """
     Arrange Cookies from raw using SimpleCookies
